@@ -1,14 +1,14 @@
 /* TimeZoneManager.h
  *
- * Copyright (C) 2004 by Cenon GmbH
+ * Copyright (C) 2004 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2004-10-06
  * modified: 2004-10-06
  */
 
-#ifndef CEN_H_TIMEZONEMANAGER
-#define CEN_H_TIMEZONEMANAGER
+#ifndef VHF_H_TIMEZONEMANAGER
+#define VHF_H_TIMEZONEMANAGER
 
 #include <AppKit/AppKit.h>
 
@@ -31,4 +31,4 @@
 
 @end
 
-#endif	// CEN_H_TIMEZONEMANAGER
+#endif	// VHF_H_TIMEZONEMANAGER
